@@ -37,10 +37,11 @@ function form_to_json(form) {
  * Voting
  */
 
-function vote(elem, value) {
+function vote(elem) {
     if ($(elem).hasClass("disabled")) {
-        return false;
+        return;
     }
+    var value = parseInt($(elem).attr("data-vote"));
     var form = $(elem).parents("form").first();
     var data = form_to_json(form);
     data['vote'] = value;
@@ -50,21 +51,25 @@ function vote(elem, value) {
         dataType: "json",
         data: data,
         success: function(response) {
-            form.replaceWith(response.html);
+            var newcontent = $(response.html);
+            form.replaceWith(newcontent);
+            setup_vote(newcontent); // re-bind events
         },
         error: function(jqXHR, textStatus, errorThrown) {
             alert(jqXHR.responseText);
         }
     });
-    return false;
 }
 
 
-function setup_vote() {
-    /*
-    $("a.youlike").click(function(e) { e.preventDefault(); vote(this, 1); });
-    $("a.youdislike").click(function(e) { e.preventDefault(); vote(this, -1); });
-    */
+function setup_vote(baseElem) {
+    if (!baseElem) {
+        baseElem = document;
+    }
+    $(baseElem).find("a.vote").click(function(e) {
+        e.preventDefault();
+        vote(this);
+    });
 }
 
 
@@ -131,9 +136,7 @@ function setup_favorites() {
                 action_field.trigger("change");
             },
             error: function(jqXHR, textStatus, errorThrown) {
-                if (jqXHR.status === 403) {
-                    alert(jqXHR.responseText);
-                }
+                alert(jqXHR.responseText);
             }
         });
     });
@@ -144,8 +147,43 @@ function setup_favorites() {
  * Replies
  */
 
-function setup_replies() {
-    $("a.reply").click(function(e) {
+function setup_emails_list(baseElem) {
+    if (!baseElem) {
+        baseElem = document;
+    }
+    // Attachements
+    $(baseElem).find(".email-info .attachments a.attachments").each(function() {
+        var att_list = $(this).next("ul.attachments-list");
+        var pos = $(this).position();
+        att_list.css("left", pos.left);
+        $(this).click(function() {
+            att_list.slideToggle('fast');
+        });
+    });
+    // Quotes
+    $(baseElem).find('div.email-body .quoted-switch a')
+        .click(function(e) {
+            e.preventDefault();
+            $(this).parent().next(".quoted-text").slideToggle('fast');
+        });
+    setup_replies(baseElem);
+}
+
+function fold_quotes(baseElem) {
+    $(baseElem).find('div.email-body .quoted-text').each(function() {
+        var linescount = $(this).text().split("\n").length;
+        if (linescount > 3) {
+            // hide if the quote is more than 3 lines long
+            $(this).hide();
+        }
+    });
+}
+
+function setup_replies(baseElem) {
+    if (!baseElem) {
+        baseElem = document;
+    }
+    $(baseElem).find("a.reply").click(function(e) {
         e.preventDefault();
         if (!$(this).hasClass("disabled")) {
             $(this).next().slideToggle("fast", function() {
@@ -155,21 +193,26 @@ function setup_replies() {
             });
         }
     });
-    $(".reply-form button[type='submit']").click(function(e) {
+    $(baseElem).find(".reply-form button[type='submit']").click(function(e) {
         e.preventDefault();
         var form = $(this).parents("form").first();
+        // remove previous error messages
+        form.find("div.reply-result").remove();
         var data = form_to_json(form);
         $.ajax({
             type: "POST",
             url: form.attr("action"),
-            //dataType: "json",
+            dataType: "json",
             data: data,
             success: function(response) {
+                var reply = $(response.message_html);
+                reply.insertAfter(form.parents(".email").first().parent());
                 form.parents(".reply-form").first().slideUp(function() {
                     form.find("textarea").val("");
+                    reply.slideDown();
                 });
                 $('<div class="reply-result"><div class="alert alert-success">'
-                  + response + '</div></div>')
+                  + response.result + '</div></div>')
                     .appendTo(form.parents('.email-info').first())
                     .delay(2000).fadeOut('slow', function() { $(this).remove(); });
             },
@@ -177,15 +220,15 @@ function setup_replies() {
                 $('<div class="reply-result"><div class="alert alert-error">'
                   + '<button type="button" class="close" data-dismiss="alert">&times;</button> '
                   + jqXHR.responseText + '</div></div>')
-                    .css("display", "none").insertBefore(form).slideDown();
+                    .css("display", "none").prependTo(form).slideDown();
             }
         });
     });
-    $(".reply-form a.cancel").click(function(e) {
+    $(baseElem).find(".reply-form a.cancel").click(function(e) {
         e.preventDefault();
         $(this).parents(".reply-form").first().slideUp();
     });
-    $(".reply-form a.quote").click(function(e) {
+    $(baseElem).find(".reply-form a.quote").click(function(e) {
         e.preventDefault();
         var quoted = $(this).parents(".email").first()
                         .find(".email-body").clone()
@@ -204,66 +247,175 @@ function setup_replies() {
         textarea.val(quoted + "\n" + textarea.val());
         textarea.focus();
     });
+    function set_new_thread(checkbox) {
+        var this_form = checkbox.parents("form").first();
+        var subj = this_form.find("input[name='subject']").parents("p").first();
+        if (checkbox.is(":checked")) {
+            subj.slideDown("fast");
+            subj.find("input").focus();
+        } else {
+            subj.slideUp("fast");
+            this_form.find("textarea").focus();
+        }
+    }
+    $(baseElem).find(".reply-form input[name='newthread']").change(function() {
+        set_new_thread($(this));
+    }).change();
 }
 
 
 /*
  * Recent activity graph
  */
-
-function activity_graph(dates, data, baseurl) {
-    var w = 500,
-        h = 300,
-        x = pv.Scale.ordinal(pv.range(32)).splitBanded(0, w, 4/5),
-        y = pv.Scale.linear(0, Math.max.apply(null, data)+1).range(0, h);
-
-    var vis = new pv.Panel()
-        .width(w)
-        .height(250)
-        .bottom(60)
-        .left(30)
-        .right(5)
-        .top(5);
-
-    var bar = vis.add(pv.Bar)
-        .data(data)
-        .event("click", function(n) { self.location = baseurl + "/" + dates[this.index].replace(/-/g, '/') + "/"; })
-        .left(function() x(this.index))
-        .width(x.range().band)
-        .bottom(0)
-        .height(y);
-
-    bar.anchor("bottom").add(pv.Label)
-        .textMargin(5)
-        .textAlign("right")
-        .textBaseline("middle")
-        .textAngle(-Math.PI / 3)
-        .text(function() xlabel(this.index));
-
-    function xlabel(ind) {
-        if (!dates[ind -1]) {
-            return dates[ind];
+function activity_graph(elem_id, dates, counts, baseurl) {
+    function merge(dates, counts) {
+        result = []
+        for(i = 0; i < dates.length; i++) {
+            result.push({
+                "date": dates[i],
+                "count": counts[i]
+            })
         }
-        prev = dates[ind - 1];
-        cur = dates[ind];
-        if (prev.substring(0,7) == cur.substring(0,7)) {
-            cur = cur.substring(8);
-        }
-        return cur;
+        return result;
     }
+    var data = merge(dates, counts);
+    var margin = {top: 20, right: 20, bottom: 100, left: 50},
+        width = 540 - margin.left - margin.right,
+        height = 330 - margin.top - margin.bottom;
 
-    vis.add(pv.Rule)
-        .data(y.ticks())
-        .bottom(function(d) Math.round(y(d)) - .5)
-        .strokeStyle(function(d) d ? "rgba(255,255,255,.3)" : "#000")
-        .add(pv.Rule)
-        .left(0)
-        .width(5)
-        .strokeStyle("#000")
-        .anchor("left").add(pv.Label)
-        .text(function(d) d.toFixed(1));
+    var format_in = d3.time.format("%Y-%m-%d");
+    var format_out = d3.time.format("%m-%d");
 
-    vis.render();
+    var x = d3.time.scale()
+        .range([0, width]);
+
+    var y = d3.scale.linear()
+        .range([height, 0]);
+
+    var xAxis = d3.svg.axis()
+        .scale(x)
+        .orient("bottom")
+        .tickFormat(format_out)
+        .ticks(d3.time.days, 2);
+
+    var yAxis = d3.svg.axis()
+        .scale(y)
+        .orient("left")
+        .ticks(5)
+        .tickSubdivide(1);
+
+    var area = d3.svg.area()
+        .x(function(d) { return x(d.date); })
+        .y0(height)
+        .y1(function(d) { return y(d.count); });
+
+    var svg = d3.select(elem_id).append("svg")
+        .attr("width", width + margin.left + margin.right)
+        .attr("height", height + margin.top + margin.bottom)
+      .append("g")
+        .attr("transform", "translate(" + margin.left + "," + margin.top + ")");
+
+    data.forEach(function(d) {
+        d.date = format_in.parse(d.date);
+        d.count = parseInt(d.count);
+    });
+
+    x.domain(d3.extent(data, function(d) { return d.date; }));
+    y.domain([0, d3.max(data, function(d) { return d.count; })]);
+
+    svg.append("path")
+      .datum(data)
+      .attr("class", "area")
+      .attr("d", area);
+
+    svg.append("g")
+      .attr("class", "x axis")
+      .attr("transform", "translate(0," + height + ")")
+      .call(xAxis)
+      .selectAll("text")
+        .attr("y", -5)
+        .attr("x", -30)
+        .attr("transform", function(d) {
+            return "rotate(-90)"
+            });
+
+    svg.append("g")
+      .attr("class", "y axis")
+      .call(yAxis)
+    .append("text")
+      .attr("transform", "rotate(-90)")
+      .attr("y", 6)
+      .attr("dy", ".71em")
+      .style("text-anchor", "end")
+      .text("Messages");
+}
+
+
+/*
+ * Thread replies list
+ */
+function update_thread_replies(url) {
+    function load_more(current_url) {
+        $.ajax({
+            dataType: "json",
+            url: current_url,
+            success: function(data) {
+                // replies
+                var newcontent = $(data.replies_html);
+                $(".replies").append(newcontent)
+                             .append($(".replies .ajaxloader"));
+                // re-bind events
+                setup_emails_list(newcontent);
+                fold_quotes(newcontent);
+                setup_disabled_tooltips(newcontent);
+                setup_vote(newcontent);
+                // load the rest if applicable
+                if (data.more_pending) {
+                    load_more(url+"&offset="+data.next_offset);
+                } else {
+                    $(".replies .ajaxloader").remove();
+                }
+            },
+            error: function(jqXHR, textStatus, errorThrown) {
+                if (jqXHR.responseText !== "") {
+                    alert(jqXHR.responseText);
+                }
+            }
+        });
+    }
+    load_more(url);
+}
+
+
+/*
+ * List descriptions on the front page
+ */
+function update_list_properties(url) {
+    $.ajax({
+        dataType: "json",
+        url: url,
+        success: function(data) {
+            $(".all-lists .mailinglist").each(function() {
+                var name = $(this).find(".list-address").text();
+                if (!data[name]) {
+                    return;
+                }
+                if (data[name]["display_name"]) {
+                    $(this).find(".list-name").text(data[name]["display_name"]);
+                }
+                if (data[name]["description"]) {
+                    $(this).find(".list-description")
+                           .text(data[name]["description"]);
+                }
+            });
+        },
+        error: function(jqXHR, textStatus, errorThrown) {
+            //alert(jqXHR.responseText);
+        },
+        complete: function(jqXHR, textStatus) {
+            $(".all-lists .mailinglist img.ajaxloader").remove();
+        }
+    });
 }
 
 
@@ -271,25 +423,6 @@ function activity_graph(dates, data, baseurl) {
  * Misc.
  */
 
-function setup_attachments() {
-    $(".email-info .attachments a.attachments").each(function() {
-        var att_list = $(this).next("ul.attachments-list");
-        var pos = $(this).position();
-        att_list.css("left", pos.left);
-        $(this).click(function() {
-            att_list.slideToggle('fast');
-        });
-    });
-}
-
-function setup_quotes() {
-    $('div.email-body .quoted-switch a')
-        .click(function(e) {
-            e.preventDefault();
-            $(this).parent().next(".quoted-text").slideToggle('fast');
-        });
-}
-
 function setup_months_list() {
     var current = $("#months-list li.current").parent().prev();
     if (!current.length) {
@@ -300,14 +433,17 @@ function setup_months_list() {
     $("#months-list").accordion({ collapsible: true, active: current });
 }
 
-function setup_disabled_tooltips() {
-    $("a.disabled").tooltip().click(function (e) {
+function setup_disabled_tooltips(baseElem) {
+    if (!baseElem) {
+        baseElem = document;
+    }
+    $(baseElem).find("a.disabled").tooltip().click(function (e) {
         e.preventDefault();
     });
 }
 
 function setup_flash_messages() {
-    $('.flashmsg').delay(3000).fadeOut('slow');
+    $('.flashmsgs .alert-success').delay(3000).fadeOut('slow');
 }
 
 
@@ -317,12 +453,10 @@ function setup_flash_messages() {
 
 $(document).ready(function() {
     setup_vote();
-    setup_attachments();
     setup_add_tag();
-    setup_quotes();
     setup_months_list();
     setup_favorites();
-    setup_replies();
+    setup_emails_list();
     setup_disabled_tooltips();
     setup_flash_messages();
 });
