@@ -20,10 +20,10 @@
 # Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
 
-from django.conf.urls.defaults import patterns, include, url
+from django.conf.urls import patterns, include, url
 from django.conf import settings
-from django.views.generic.simple import direct_to_template
-from api import EmailResource, ThreadResource, SearchResource
+from django.views.generic.base import TemplateView
+from api import ListResource, EmailResource, ThreadResource, SearchResource
 
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns
 from django.contrib.auth.views import login as login_view
@@ -33,13 +33,19 @@ from django.contrib.auth.views import logout as logout_view
 from django.contrib import admin
 admin.autodiscover()
 
+from hyperkitty.views import TextTemplateView
+
+
+
 urlpatterns = patterns('hyperkitty.views',
     # Index
     url(r'^/$', 'pages.index', name='index'),
     url(r'^$', 'pages.index', name='root'),
+    url(r'^lists-properties$', 'pages.list_properties', name='list_properties'),
 
     # Account
-    url(r'^accounts/login/$', login_view, {'template_name': 'login.html', 'SSL': True}, name='user_login'),
+    #url(r'^accounts/login/$', login_view, {'template_name': 'login.html', 'SSL': True}, name='user_login'),
+    url(r'^accounts/login/$', 'accounts.login_view', {'template_name': 'login.html', 'SSL': True}, name='user_login'),
     url(r'^accounts/logout/$', logout_view, {'next_page': '/'}, name='user_logout'),
     url(r'^accounts/profile/$', 'accounts.user_profile', name='user_profile'),
     url(r'^accounts/register/$', 'accounts.user_registration', {'SSL': True}, name='user_registration'),
@@ -70,6 +76,8 @@ urlpatterns = patterns('hyperkitty.views',
     # Thread
     url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/$',
         'thread.thread_index', name='thread'),
+    url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/replies$',
+        'thread.replies', name='thread_replies'),
     url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/addtag$',
         'thread.add_tag', name='add_tag'),
     url(r'^list/(?P<mlist_fqdn>[^/@]+@[^/@]+)/thread/(?P<threadid>\w+)/favorite$',
@@ -88,8 +96,10 @@ urlpatterns = patterns('hyperkitty.views',
 
 
     # REST API
-    url(r'^api/$', direct_to_template, {"template": "api.html"}),
-    url(r'^api/email\/(?P<mlist_fqdn>[^/@]+@[^/@]+)\/(?P<hashid>.*)/',
+    url(r'^api/$', TemplateView.as_view(template_name="api.html")),
+    url(r'^api/list\/',
+        ListResource.as_view(), name="api_list"),
+    url(r'^api/email\/(?P<mlist_fqdn>[^/@]+@[^/@]+)\/(?P<messageid>.*)/',
         EmailResource.as_view(), name="api_email"),
     url(r'^api/thread\/(?P<mlist_fqdn>[^/@]+@[^/@]+)\/(?P<threadid>.*)/',
         ThreadResource.as_view(), name="api_thread"),
@@ -103,8 +113,7 @@ urlpatterns = patterns('hyperkitty.views',
     url(r'^admin/', include(admin.site.urls), {"SSL": True}),
 
     # Robots.txt
-    url(r'^robots\.txt$', direct_to_template,
-     {'template': 'robots.txt', 'mimetype': 'text/plain'}),
+    url(r'^robots\.txt$', TextTemplateView.as_view(template_name="robots.txt")),
 
     # Social Auth
     url(r'', include('social_auth.urls'), {"SSL": True}),
