@@ -29,9 +29,11 @@ from django.core.urlresolvers import reverse
 from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 from django.utils import formats
 from django.utils.dateformat import format as date_format
+from django.http import Http404
 
 from hyperkitty.models import Tag, Favorite
-from hyperkitty.lib import get_months, get_store, get_display_dates
+from hyperkitty.lib import get_months, get_store, get_display_dates, daterange
+from hyperkitty.lib import FLASH_MESSAGES
 from hyperkitty.lib.voting import get_votes
 from forms import SearchForm
 
@@ -40,11 +42,6 @@ if settings.USE_MOCKUPS:
     from hyperkitty.lib.mockup import generate_top_author, generate_thread_per_category
 
 
-FLASH_MESSAGES = {
-    "sent-ok": "The message has been sent successfully.",
-}
-
-
 def archives(request, mlist_fqdn, year=None, month=None, day=None):
     if year is None and month is None:
         today = datetime.date.today()
@@ -75,6 +72,8 @@ def archives(request, mlist_fqdn, year=None, month=None, day=None):
 
 
 def _thread_list(request, mlist, threads, template_name='thread_list.html', extra_context={}):
+    if mlist is None:
+        raise Http404("No archived mailing-list by that name.")
     store = get_store(request)
     search_form = SearchForm(auto_id=False)
 
@@ -144,7 +143,8 @@ def _thread_list(request, mlist, threads, template_name='thread_list.html', extr
     flash_messages = []
     flash_msg = request.GET.get("msg")
     if flash_msg:
-        flash_msg = { "type": "success", "msg": FLASH_MESSAGES[flash_msg] }
+        flash_msg = { "type": FLASH_MESSAGES[flash_msg][0],
+                      "msg": FLASH_MESSAGES[flash_msg][1] }
         flash_messages.append(flash_msg)
 
     context = {
@@ -160,7 +160,6 @@ def _thread_list(request, mlist, threads, template_name='thread_list.html', extr
     return render(request, template_name, context)
 
 
-
 def overview(request, mlist_fqdn=None):
     if not mlist_fqdn:
         return redirect('/')
@@ -210,6 +209,10 @@ def overview(request, mlist_fqdn=None):
     emails_in_month = store.get_messages(list_name=mlist.name,
                                          start=begin_date, end=end_date)
     dates = defaultdict(lambda: 0) # no activity by default
+    # populate with all days before adding data.
+    for single_date in daterange(begin_date, end_date):
+        dates[single_date.strftime("%Y-%m-%d")] = 0
+
     for email in emails_in_month:
         date_str = email.date.strftime("%Y-%m-%d")
         dates[date_str] = dates[date_str] + 1
