@@ -31,6 +31,7 @@ from django.template import RequestContext, loader
 from django.shortcuts import render
 from django.core.urlresolvers import reverse
 from django.core.exceptions import SuspiciousOperation
+import robot_detection
 
 from hyperkitty.models import Tag, Favorite
 from forms import SearchForm, AddTagForm, ReplyForm
@@ -38,6 +39,39 @@ from hyperkitty.lib import get_months, get_store, stripped_subject
 from hyperkitty.lib.voting import set_message_votes
 
 
+def _get_thread_replies(request, thread, offset=1, limit=None):
+    '''
+    Get and sort the replies for a thread.
+    By default, offset = 1 to skip the original message.
+    '''
+    if not thread:
+        raise Http404
+
+    if "sort" in request.GET and request.GET["sort"] == "date":
+        sort_mode = "date"
+        emails = thread.emails
+    else:
+        sort_mode = "thread"
+        emails = thread.emails_by_reply
+
+    # XXX: Storm-specific
+    emails = emails.find()
+    emails.config(offset=offset)
+    if limit is not None:
+        emails.config(limit=limit)
+
+    emails = list(emails)
+    for email in emails:
+        # Extract all the votes for this message
+        set_message_votes(email, request.user)
+        if sort_mode == "thread":
+            email.level = email.thread_depth - 1 # replies start ragged left
+            if email.level > 5:
+                email.level = 5
+
+    return emails
+
+
 def thread_index(request, mlist_fqdn, threadid, month=None, year=None):
     ''' Displays all the email for a given thread identifier '''
     search_form = SearchForm(auto_id=False)
@@ -47,25 +81,8 @@ def thread_index(request, mlist_fqdn, threadid, month=None, year=None):
         raise Http404
     prev_thread, next_thread = store.get_thread_neighbors(mlist_fqdn, threadid)
 
-    if "sort" in request.GET and request.GET["sort"] == "date":
-        sort_mode = "date"
-        emails = thread.emails
-    else:
-        sort_mode = "thread"
-        emails = thread.emails_by_reply
-
-    participants = {}
-    for email in emails:
-        # Extract all the votes for this message
-        set_message_votes(email, request.user)
-
-        # Statistics on how many participants and messages this month
-        participants[email.sender_name] = email.sender_email
-
-        if sort_mode == "thread":
-            email.level = email.thread_depth - 1 # replies start ragged left
-            if email.level > 5:
-                email.level = 5
+    sort_mode = request.GET.get("sort", "thread")
+    set_message_votes(thread.starting_email, request.user)
 
     from_url = reverse("thread", kwargs={"mlist_fqdn":mlist_fqdn,
                                          "threadid":threadid})
@@ -95,17 +112,22 @@ def thread_index(request, mlist_fqdn, threadid, month=None, year=None):
     mlist = store.get_list(mlist_fqdn)
     subject = stripped_subject(mlist, thread.starting_email.subject)
 
+    # TODO: eventually move to a middleware ?
+    # http://djangosnippets.org/snippets/1865/
+    is_bot = True
+    user_agent = request.META.get('HTTP_USER_AGENT', None)
+    if user_agent:
+        is_bot = robot_detection.is_robot(user_agent)
+
     context = {
-        'mlist' : mlist,
-        'threadid' : threadid,
+        'mlist': mlist,
+        'threadid': threadid,
         'subject': subject,
-        'tags' : tags,
+        'tags': tags,
         'search_form': search_form,
         'addtag_form': tag_form,
         'month': thread.date_active,
-        'participants': participants,
         'first_mail': thread.starting_email,
-        'replies': list(emails)[1:],
         'neighbors': (prev_thread, next_thread),
         'months_list': get_months(store, mlist.name),
         'days_inactive': days_inactive.days,
@@ -113,10 +135,46 @@ def thread_index(request, mlist_fqdn, threadid, month=None, year=None):
         'sort_mode': sort_mode,
         'fav_action': fav_action,
         'reply_form': ReplyForm(),
+        'is_bot': is_bot,
+        'participants': thread.participants,
     }
+    context["participants"].sort(key=lambda x: x[0].lower())
+
+    if is_bot:
+        # Don't rely on AJAX to load the replies
+        context["replies"] = _get_thread_replies(request, thread)
+
     return render(request, "thread.html", context)
 
 
+def replies(request, mlist_fqdn, threadid):
+    """Get JSON encoded lists with the replies and the participants"""
+    chunk_size = 5
+    offset = int(request.GET.get("offset", "1"))
+    store = get_store(request)
+    thread = store.get_thread(mlist_fqdn, threadid)
+    mlist = store.get_list(mlist_fqdn)
+    context = {
+        'mlist': mlist,
+        'threadid': threadid,
+        'reply_form': ReplyForm(),
+    }
+    context["replies"] = _get_thread_replies(request, thread, offset=offset,
+                                             limit=chunk_size)
+
+    replies_tpl = loader.get_template('threads/replies.html')
+    replies_html = replies_tpl.render(RequestContext(request, context))
+    response = {"replies_html": replies_html,
+                "more_pending": False,
+                "next_offset": None,
+               }
+    if len(context["replies"]) == chunk_size:
+        response["more_pending"] = True
+        response["next_offset"] = offset + chunk_size
+    return HttpResponse(json.dumps(response),
+                        mimetype='application/javascript')
+
+
 def add_tag(request, mlist_fqdn, threadid):
     """ Add a tag to a given thread. """
     if not request.user.is_authenticated():
